(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65906,       1996]*)
(*NotebookOutlinePosition[     66871,       2031]*)
(*  CellTagsIndexPosition[     66775,       2024]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Converting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebooks to Microsoft Word format."
}], "Title"],

Cell[TextData[{
  "Mike Honeychurch\n",
  ButtonBox["m.honeychurch@uq.edu.au",
    ButtonData:>{
      URL[ "mailto:m.honeychurch@uq.edu.au"], None},
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["Version 0.1", "Text"],

Cell["last modified Tuesday, July 12, 2005 at 14:57", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  ButtonBox["Introduction",
    ButtonStyle->"SectionButton"]
}], "Section"],

Cell[TextData[{
  "So you've figured out how to prepare really nice documents using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " but you find yourself collaborating with someone else who only ever uses \
Microsoft Word. Your collaborators want to be able to edit the document you \
have written so you need to provide them with something that they can both \
read and edit. Do you forget all about using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for document creation and wave the white flag or do you persevere and \
look for a method of converting your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook into the ubiquitous Word format? If you've faced this problem \
perhaps this notebook can be of some help."
}], "Text"],

Cell[TextData[{
  "This notebook is by no means a definitive example of how to convert a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook to Microsoft Word but rather contains a few things that I have \
found useful. Since the question of how best to convert notebooks to Word is \
occasionally asked in MathGroup I thought I would write this brief example."
}], "Text"],

Cell[TextData[{
  "The conversion approach I've taken is rather indirect but in my experience \
provides the best outcome. In brief it involves first converting the notebook \
to ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " using the File\[RightPointer]Save As Special\[Ellipsis] menu command. The \
resulting ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " document is then converted to rich text format (RTF) using the freeware \
application latex2rtf. The resulting RTF file can then be opened in Word and \
saved as a Word document."
}], "Text"],

Cell[TextData[{
  "Now the thing is that if you only have plain text in your notebook then \
you can simply cut and paste into word but the trouble and problems arise if \
you have inline equations and figures. Providing that you can save your \
notebook into a ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file, latex2rtf will convert the entire ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file with equations and figures into an RTF file. Better still the \
equations will be converted into \"clickable\" fields that can be edited \
using the inbuilt equation editor in Word."
}], "Text"],

Cell[TextData[{
  "To get started you'll need to download a copy of latex2rtf. It is \
available at ",
  ButtonBox["http://latex2rtf.sourceforge.net/",
    ButtonData:>{
      URL[ "http://latex2rtf.sourceforge.net/"], None},
    ButtonStyle->"Hyperlink"],
  ". Versions are available for UNIX and windows. The examples contained in \
this folder were generated using version 1.9.16a for UNIX. I compiled it on \
an Apple G4 powermac running OS X 10.3.9. Mac users can also obtain latex2rtf \
via ",
  ButtonBox["Fink",
    ButtonData:>{
      URL[ "http://fink.sourceforge.net/"], None},
    ButtonStyle->"Hyperlink"],
  ". Thats it. The only other things you will need to test this is a \
notebook, such as this one, containing equations and figures, preferably also \
some means of editing and checking the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " document that you save, this is not vital but can be useful, and a copy \
of MS Word."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  ButtonBox["Step One",
    ButtonStyle->"SectionButton"]
}], "Section"],

Cell[TextData[{
  "In this section we'll generate some equation cells and figures and also \
some inline equations like this ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2 + 2  y = z\)]],
  " and this ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%b\( e\^\(-x\)\) \(x\^3\) 
          y \[DifferentialD]x\)]],
  ". I've deliberately made some numbered equation cells that contain \
multi-line equations. These require some small editing of the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file before they can be successfully converted by latex2rtf. I've found \
that for the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " conversion to work best you need to name you numbered equation cells \
\"NumberedEquation.\" If you were to open the style sheet and change the \
name, without changing the actual styling the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " conversion looks a bit messy. You can try this out for yourself. This is \
presumably because the converter has been programmed to recognise only cells \
called \"NumberedEquation\" as numbered equations. If you know ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " fixing this in the output file would presumably be trivial. Unfortunately \
I do not know ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  ". The remaining part of this section contains some equations, a plot and \
some filler text."
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x\^2 + 2  y = z\)]]], "NumberedEquation"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%b\( e\^\(-x\)\) \(x\^3\) 
        y \[DifferentialD]x\)]]], "NumberedEquation"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        FractionBox[
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], 
                StyleBox["\[CapitalGamma]",
                  FontSlant->"Plain"]}]], 
            StyleBox["A",
              FontSlant->"Plain"]], 
          StyleBox["dt",
            FontSlant->"Italic"]], "=", "\[AlignmentMarker]", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              SubscriptBox["k", 
                StyleBox["f1",
                  FontSlant->"Plain"]]}], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["A",
                FontSlant->"Plain"]]}], "+", 
          RowBox[{
            SubscriptBox["k", 
              StyleBox["b1",
                FontSlant->"Plain"]], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["B",
                FontSlant->"Plain"]]}], "+", 
          RowBox[{\(k\_2\), 
            SubscriptBox["\[CapitalGamma]", 
              RowBox[{
                StyleBox["C",
                  FontSlant->"Plain"], ".", 
                StyleBox["S",
                  FontSlant->"Plain"]}]]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        FractionBox[
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], 
                StyleBox["\[CapitalGamma]",
                  FontSlant->"Plain"]}]], 
            StyleBox["B",
              FontSlant->"Plain"]], 
          StyleBox["dt",
            FontSlant->"Italic"]], "=", "\[AlignmentMarker]", 
        RowBox[{
          RowBox[{
            RowBox[{"-", 
              RowBox[{"(", 
                RowBox[{
                  SubscriptBox["k", 
                    StyleBox["f2",
                      FontSlant->"Plain"]], "+", 
                  SubscriptBox["k", 
                    StyleBox["b1",
                      FontSlant->"Plain"]]}], ")"}]}], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["B",
                FontSlant->"Plain"]]}], "+", 
          RowBox[{
            SubscriptBox["k", 
              StyleBox["b2",
                FontSlant->"Plain"]], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["C",
                FontSlant->"Plain"]]}], "\[AlignmentMarker]", "+", 
          RowBox[{
            SubscriptBox["k", 
              StyleBox["f1",
                FontSlant->"Plain"]], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["A",
                FontSlant->"Plain"]]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        FractionBox[
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], 
                StyleBox["\[CapitalGamma]",
                  FontSlant->"Plain"]}]], 
            StyleBox["C",
              FontSlant->"Plain"]], 
          StyleBox["dt",
            FontSlant->"Italic"]], "=", "\[AlignmentMarker]", 
        RowBox[{
          RowBox[{
            SubscriptBox["k", 
              StyleBox["f2",
                FontSlant->"Plain"]], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["B",
                FontSlant->"Plain"]]}], "-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(k\_\(+1\)\), 
                  RowBox[{
                    SubscriptBox["c", 
                      StyleBox["S",
                        FontSlant->"Plain"]], "(", \(0, t\), ")"}]}], "+", 
                SubscriptBox["k", 
                  StyleBox["b2",
                    FontSlant->"Plain"]]}], ")"}], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["C",
                FontSlant->"Plain"]]}], "+", 
          RowBox[{\(k\_\(-1\)\), 
            SubscriptBox["\[CapitalGamma]", 
              RowBox[{
                StyleBox["C",
                  FontSlant->"Plain"], ".", 
                StyleBox["S",
                  FontSlant->"Plain"]}]]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        FractionBox[
          SubscriptBox[
            StyleBox[
              RowBox[{
                StyleBox["d",
                  FontSlant->"Italic"], 
                StyleBox["\[CapitalGamma]",
                  FontSlant->"Plain"]}]], 
            StyleBox[\(C . S\),
              FontSlant->"Plain"]], 
          StyleBox["dt",
            FontSlant->"Italic"]], "=", "\[AlignmentMarker]", 
        RowBox[{
          RowBox[{\(k\_\(+1\)\), 
            RowBox[{
              SubscriptBox["c", 
                StyleBox["S",
                  FontSlant->"Plain"]], "(", \(0, t\), ")"}], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["C",
                FontSlant->"Plain"]]}], "-", 
          RowBox[{\((k\_\(-1\) + k\_2)\), 
            SubscriptBox["\[CapitalGamma]", 
              RowBox[{
                StyleBox["C",
                  FontSlant->"Plain"], ".", 
                StyleBox["S",
                  FontSlant->"Plain"]}]]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{
        RowBox[{"-", 
          SubscriptBox[
            RowBox[{"D", "(", 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  RowBox[{
                    SubscriptBox["c", 
                      StyleBox["S",
                        FontSlant->"Plain"]], "(", \(x, t\), 
                    ")"}]}], \(\[PartialD]x\)], ")"}], \(x = 0\)]}], "=", 
        "\[AlignmentMarker]", 
        RowBox[{
          RowBox[{\(-k\_\(+1\)\), 
            RowBox[{
              SubscriptBox["c", 
                StyleBox["S",
                  FontSlant->"Plain"]], "(", \(0, t\), ")"}], 
            SubscriptBox["\[CapitalGamma]", 
              StyleBox["C",
                FontSlant->"Plain"]]}], "+", 
          RowBox[{\(k\_\(-1\)\), 
            SubscriptBox["\[CapitalGamma]", 
              RowBox[{
                StyleBox["C",
                  FontSlant->"Plain"], ".", 
                StyleBox["S",
                  FontSlant->"Plain"]}]]}]}]}], TraditionalForm]}],
  TextAlignment->AlignmentMarker]], "NumberedEquation",
  CellTags->"eqn1"],

Cell["\<\
Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam \
nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. \
Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit \
lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure \
dolor in hendrerit in vulputate velit esse molestie consequat, vel illum \
dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio \
dignissim qui blandit praesent luptatum zzril delenit a\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[Sin[x], {x, 0, 2  \[Pi]}]\)], "Input",
  CellLabel->"In[208]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .31831 
%%ImageSize: 288 91.673 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.159154 0.151576 [
[.02381 -0.0125 -5.75 -17 ]
[.02381 -0.0125 5.75 0 ]
[.17539 -0.0125 -5.75 -17 ]
[.17539 -0.0125 5.75 0 ]
[.32696 -0.0125 -5.75 -17 ]
[.32696 -0.0125 5.75 0 ]
[.47854 -0.0125 -5.75 -17 ]
[.47854 -0.0125 5.75 0 ]
[.63011 -0.0125 -5.75 -17 ]
[.63011 -0.0125 5.75 0 ]
[.78169 -0.0125 -5.75 -17 ]
[.78169 -0.0125 5.75 0 ]
[.93327 -0.0125 -5.75 -17 ]
[.93327 -0.0125 5.75 0 ]
[ 0 0 -0.25 0 ]
[-0.0125 .00758 -22.4375 -8.5 ]
[-0.0125 .00758 0 8.5 ]
[-0.0125 .08337 -33.6875 -8.5 ]
[-0.0125 .08337 0 8.5 ]
[-0.0125 .15915 -11.5 -8.5 ]
[-0.0125 .15915 0 8.5 ]
[-0.0125 .23494 -22.75 -8.5 ]
[-0.0125 .23494 0 8.5 ]
[-0.0125 .31073 -11.5 -8.5 ]
[-0.0125 .31073 0 8.5 ]
[ 0 0 -0.25 0 ]
[ 0 .31831 .25 0 ]
[ 1 0 .25 0 ]
[ 0 0 0 0 ]
[ 1 .31831 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 0 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.17539 0 m
.17539 .00625 L
s
gsave
.17539 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.32696 0 m
.32696 .00625 L
s
gsave
.32696 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.47854 0 m
.47854 .00625 L
s
gsave
.47854 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.63011 0 m
.63011 .00625 L
s
gsave
.63011 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.78169 0 m
.78169 .00625 L
s
gsave
.78169 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.93327 0 m
.93327 .00625 L
s
gsave
.93327 -0.0125 -66.75 -21 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.05412 0 m
.05412 .00375 L
s
.08444 0 m
.08444 .00375 L
s
.11476 0 m
.11476 .00375 L
s
.14507 0 m
.14507 .00375 L
s
.2057 0 m
.2057 .00375 L
s
.23602 0 m
.23602 .00375 L
s
.26633 0 m
.26633 .00375 L
s
.29665 0 m
.29665 .00375 L
s
.35728 0 m
.35728 .00375 L
s
.38759 0 m
.38759 .00375 L
s
.41791 0 m
.41791 .00375 L
s
.44822 0 m
.44822 .00375 L
s
.50885 0 m
.50885 .00375 L
s
.53917 0 m
.53917 .00375 L
s
.56948 0 m
.56948 .00375 L
s
.5998 0 m
.5998 .00375 L
s
.66043 0 m
.66043 .00375 L
s
.69074 0 m
.69074 .00375 L
s
.72106 0 m
.72106 .00375 L
s
.75137 0 m
.75137 .00375 L
s
.81201 0 m
.81201 .00375 L
s
.84232 0 m
.84232 .00375 L
s
.87264 0 m
.87264 .00375 L
s
.90295 0 m
.90295 .00375 L
s
.96358 0 m
.96358 .00375 L
s
.9939 0 m
.9939 .00375 L
s
.5 Mabswid
0 0 m
1 0 L
s
.25 Mabswid
0 .00758 m
.00625 .00758 L
s
gsave
-0.0125 .00758 -83.4375 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.938 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .08337 m
.00625 .08337 L
s
gsave
-0.0125 .08337 -94.6875 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.938 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .15915 m
.00625 .15915 L
s
gsave
-0.0125 .15915 -72.5 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .23494 m
.00625 .23494 L
s
gsave
-0.0125 .23494 -83.75 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .31073 m
.00625 .31073 L
s
gsave
-0.0125 .31073 -72.5 -12.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 16.000 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 15.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02274 m
.00375 .02274 L
s
0 .03789 m
.00375 .03789 L
s
0 .05305 m
.00375 .05305 L
s
0 .06821 m
.00375 .06821 L
s
0 .09852 m
.00375 .09852 L
s
0 .11368 m
.00375 .11368 L
s
0 .12884 m
.00375 .12884 L
s
0 .144 m
.00375 .144 L
s
0 .17431 m
.00375 .17431 L
s
0 .18947 m
.00375 .18947 L
s
0 .20463 m
.00375 .20463 L
s
0 .21978 m
.00375 .21978 L
s
0 .2501 m
.00375 .2501 L
s
0 .26526 m
.00375 .26526 L
s
0 .28042 m
.00375 .28042 L
s
0 .29557 m
.00375 .29557 L
s
.5 Mabswid
0 0 m
0 .31831 L
s
.25 Mabswid
.02381 .31206 m
.02381 .31831 L
s
.17539 .31206 m
.17539 .31831 L
s
.32696 .31206 m
.32696 .31831 L
s
.47854 .31206 m
.47854 .31831 L
s
.63011 .31206 m
.63011 .31831 L
s
.78169 .31206 m
.78169 .31831 L
s
.93327 .31206 m
.93327 .31831 L
s
.125 Mabswid
.05412 .31456 m
.05412 .31831 L
s
.08444 .31456 m
.08444 .31831 L
s
.11476 .31456 m
.11476 .31831 L
s
.14507 .31456 m
.14507 .31831 L
s
.2057 .31456 m
.2057 .31831 L
s
.23602 .31456 m
.23602 .31831 L
s
.26633 .31456 m
.26633 .31831 L
s
.29665 .31456 m
.29665 .31831 L
s
.35728 .31456 m
.35728 .31831 L
s
.38759 .31456 m
.38759 .31831 L
s
.41791 .31456 m
.41791 .31831 L
s
.44822 .31456 m
.44822 .31831 L
s
.50885 .31456 m
.50885 .31831 L
s
.53917 .31456 m
.53917 .31831 L
s
.56948 .31456 m
.56948 .31831 L
s
.5998 .31456 m
.5998 .31831 L
s
.66043 .31456 m
.66043 .31831 L
s
.69074 .31456 m
.69074 .31831 L
s
.72106 .31456 m
.72106 .31831 L
s
.75137 .31456 m
.75137 .31831 L
s
.81201 .31456 m
.81201 .31831 L
s
.84232 .31456 m
.84232 .31831 L
s
.87264 .31456 m
.87264 .31831 L
s
.90295 .31456 m
.90295 .31831 L
s
.96358 .31456 m
.96358 .31831 L
s
.9939 .31456 m
.9939 .31831 L
s
.5 Mabswid
0 .31831 m
1 .31831 L
s
.25 Mabswid
.99375 .00758 m
1 .00758 L
s
.99375 .08337 m
1 .08337 L
s
.99375 .15915 m
1 .15915 L
s
.99375 .23494 m
1 .23494 L
s
.99375 .31073 m
1 .31073 L
s
.125 Mabswid
.99625 .02274 m
1 .02274 L
s
.99625 .03789 m
1 .03789 L
s
.99625 .05305 m
1 .05305 L
s
.99625 .06821 m
1 .06821 L
s
.99625 .09852 m
1 .09852 L
s
.99625 .11368 m
1 .11368 L
s
.99625 .12884 m
1 .12884 L
s
.99625 .144 m
1 .144 L
s
.99625 .17431 m
1 .17431 L
s
.99625 .18947 m
1 .18947 L
s
.99625 .20463 m
1 .20463 L
s
.99625 .21978 m
1 .21978 L
s
.99625 .2501 m
1 .2501 L
s
.99625 .26526 m
1 .26526 L
s
.99625 .28042 m
1 .28042 L
s
.99625 .29557 m
1 .29557 L
s
.5 Mabswid
1 0 m
1 .31831 L
s
1 0 0 r
.02381 .15915 m
.06244 .19737 L
.10458 .23616 L
.14415 .26725 L
.18221 .29026 L
.20178 .29896 L
.21267 .3028 L
.22272 .30569 L
.23293 .30797 L
.23832 .3089 L
.24402 .30968 L
.24641 .30994 L
.24897 .31018 L
.25119 .31035 L
.25361 .3105 L
.25507 .31058 L
.25643 .31063 L
.25773 .31067 L
.2584 .31069 L
.25912 .3107 L
.25983 .31072 L
.26048 .31072 L
.26176 .31073 L
.26293 .31073 L
.26416 .31071 L
.26538 .31069 L
.26607 .31067 L
.26671 .31065 L
.26912 .31056 L
.27131 .31044 L
.27364 .31028 L
.27847 .30983 L
.2838 .30915 L
.29326 .3075 L
.30213 .30542 L
.32232 .29885 L
.34082 .29065 L
.38045 .26669 L
.41855 .23674 L
.45911 .19955 L
.49816 .16099 L
.53966 .11995 L
.57964 .08313 L
.61811 .05264 L
.63759 .0397 L
.65902 .02774 L
.67938 .01881 L
.69843 .01274 L
.70884 .01039 L
.71396 .0095 L
Mistroke
.71872 .00882 L
.72301 .00833 L
.72758 .00794 L
.7302 .00778 L
.73148 .00772 L
.73266 .00768 L
.73371 .00764 L
.73487 .00761 L
.73603 .00759 L
.73725 .00758 L
.73856 .00758 L
.73977 .00759 L
.7404 .0076 L
.7411 .00761 L
.74251 .00764 L
.74375 .00768 L
.74508 .00774 L
.74748 .00787 L
.74985 .00803 L
.75235 .00825 L
.7568 .00873 L
.76198 .00946 L
.7668 .01029 L
.77773 .01273 L
.78828 .01581 L
.79823 .01935 L
.81683 .02757 L
.85534 .05071 L
.89632 .08292 L
.93577 .11921 L
.97371 .15667 L
.97619 .15915 L
Mfstroke
0 0 m
1 0 L
1 .31831 L
0 .31831 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[208]:=",
  ImageSize->{288, 91.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000RB000`400?l00000o`00003ooooIfMVa
omWIf@00oooIfMVaomWIf@00oooIfMVaomWIf@00oooIfMVaomWIf@00oooIfMVaomWIf@00oooIfMVa
omWIf@00oooIfMVaomWIf@00oooIfMVaomWIf@00oooIfMVaomWIf@00GooIfMT01_o:b/[o>CTio`00
0?l0003oB4Q8okbl_2OofMWI1ol0000UomWIf@[o000000?o_;blomWIfOoIfMT08OoIfMT00on][Jgo
>CTio`000002o`000003oa`L7?mFEUKo_;bl02gofMWI0ol0000UomWIf@03ojf][Oli>CWo000000;o
000000?o:b/[oh:2P_oIfMT0:?oIfMT01_nOWioo>CTio`000?l0003o71`Loh:2PSOofMWI001NomWI
f@03ol[:b_l>3Pko71`L00;ob/[:00?o71`Lo`000?nl_;`09ooIfMT01OmUIFGo0000o`000?l0003o
T92@02KofMWI00?o[Jf]o`000?l000001ol000000on@T93ofMWIomWIf@0QomWIf@Co000000Go3Ph>
oinOWoo:b/[o>CTioeIFEP0/omWIf@?o00009OoIfMT7o`000003oa`L7?n][JgofMWI02GofMWI00So
IFEUo`000?l>3Pko_;blomWIfOmFEUKo0000odQ8B3KofMWI001NomWIf@03ob/[:ol0003oT92@00;o
fMWI00?oT92@o`000?l[:b/0:?oIfMT3o`0002SofMWI00?o[Jf]o`000?l000001_l000000omUIFGo
fMWIomWIf@0QomWIf@05oeIFE_l0003o0000odQ8B?o:b/X00_oIfMT00onl_;co0000ocTi>@0[omWI
f@?o00009OoIfMT02_li>CWo0000o`h>3_mFEUKo[Jf]omWIfOnl_;co71`Lo`000?o:b/XTomWIf@04
oinOWol0003o0000oh:2PP;ofMWI00Cob/[:o`000?l0003oPX:2=OoIfMT005gofMWI00Co[Jf]o`00
0?l0003o_;bl0_oIfMT01?o:b/[o0000o`000?n][JdWomWIf@?o0000:OoIfMT00on][Jgo:b/[ol[:
bP03omWIf@03okbl_?lL71co:b/[02_ofMWI0_l000000on2PX;ofMWIomWIf@0QomWIf@_o0000:ooI
fMT00onl_;co0000odQ8B00TomWIf@04odQ8B?l0003o0000okbl_0?ofMWI0_l000000ol[:b_ofMWI
omWIf@0comWIf@00GOoIfMT00omFEUKo0000o`000004omWIf@;o000000?oEUIFomWIfOoIfMT09OoI
fMT3o`0002[ofMWI00?o[Jf]ob/[:oo:b/X00ooIfMT00onOWioo0000omWIf@0YomWIf@04ol[:b_l0
003o0000oa`L72?ofMWI2ol0000/omWIf@03o`000?l>3PkofMWI02?ofMWI00?o71`Lo`000?l00000
1?oIfMT3o`0003GofMWI001MomWIf@03ob/[:ol0003o000000CofMWI0_l000000ol[:b_ofMWIomWI
f@0UomWIf@?o0000:ooIfMT00on][Jgo71`Lojf][@0^omWIf@04oh:2P_l0003o0000o`0002?ofMWI
2ol0000[omWIf@03oh:2P_l0003o000002CofMWI0ol00004omWIf@?o0000=OoIfMT005gofMWI0ol0
0004omWIf@?o00009ooIfMT3o`0002cofMWI00?oLg=co`000?n][Jd0;?oIfMT00on][Jgo0000o`00
0002o`0002?ofMWI0_li>CT5omWIf@?o0000:ooIfMT01?n2PX;o0000o`000?l0000TomWIf@?o0000
0ooIfMT01?nl_;co0000o`000?l0000eomWIf@00GOoIfMT3o`0000CofMWI0ol0000WomWIf@?o0000
;OoIfMT00ol[:b_o0000ojf][@0YomWIf@03ol[:b_mUIFGo000000?o000000?oB4Q8omWIfOoIfMT0
8OoIfMT00oo:b/[o71`LofEUI@04omWIf@?o00009ooIfMT01?nl_;coWinOog=cLolL71`3o`000003
ocTi>OoIfMWofMWI02;ofMWI0ol00003omWIf@04oh:2P_l0003o0000odQ8B3GofMWI001MomWIf@?o
00001?oIfMT3o`0002OofMWI0ol0000]omWIf@04oi2@T?l0003o71`Lol[:bRSofMWI00?o:b/[o`00
0?l000000_l000000olL71cob/[:omWIf@0SomWIf@03ojf][Ol0003oT92@00?ofMWI0ol0000VomWI
f@03o`h>3_l0003o000000Go000000?o[Jf]omWIfOoIfMT08_oIfMT01_l[:b_o0000o`000?nOWioo
fMWIoinOW`?o000000?o_;blomWIfOoIfMT0<ooIfMT005gofMWI0ol00004omWIf@?o00009ooIfMT3
o`0002kofMWI0_l000000omUIFGofMWIomWIf@0WomWIf@05ojf][OlL71co0000ofEUIOo:b/X09_oI
fMT00on2PX;o0000ojf][@02omWIf@?o00009_oIfMT00om8B4So0000o`000004o`000003oinOWooI
fMWofMWI02?ofMWI00?oEUIFo`000?l000000_l>3Ph2o`000003odQ8B?o:b/[ofMWI03GofMWI001M
omWIf@03ob/[:ol0003o000000CofMWI0_l000000ol[:b_ofMWIomWIf@0UomWIf@?o0000;_oIfMT2
o`000003o`h>3_oIfMWofMWI02SofMWI00CoWinOo`000?lL71co_;bl9ooIfMT01?m8B4So71`Lol[:
b_oIfMT3o`0002KofMWI00OoPX:2o`000?l0003o71`LocTi>On2PX;ob/[:02KofMWI00Co_;blo`00
0?l0003o3Ph>>ooIfMT005gofMWI00?oEUIFo`000?l000001?oIfMT2o`000003oeIFE_oIfMWofMWI
02GofMWI0ol0000WomWIf@03oa`L7?nOWioofMWI00?ofMWI00CoPX:2o`000?l0003o0000:ooIfMT2
o`000003ocTi>OoIfMWofMWI02KofMWI00?o:b/[ocTi>OoIfMT00ol0000VomWIf@03okbl_?l>3Pko
fMWI02_ofMWI00CoIFEUo`000?l0003oT92@>_oIfMT005gofMWI00Co[Jf]o`000?l0003ob/[:0_oI
fMT01?o:b/[o0000o`000?n][JdWomWIf@?o00009ooIfMT00on2PX;o0000oh:2PP02omWIf@03oi2@
T?l0003o000000;o00009OoIfMT00oli>CWoT92@omWIf@02omWIf@04okbl_?l0003o0000o`0002So
fMWI00?ob/[:oa`L7?mUIFD00ol0000WomWIf@03o`h>3_nl_;cofMWI02_ofMWI00CoB4Q8o`000?l0
003o[Jf]>OoIfMT005kofMWI00?o:b/[o`000?n@T9000_oIfMT00on@T93o0000ob/[:`0VomWIf@03
ob/[:omFEUKo000000;o0000:?oIfMT00olL71co0000o`000005o`000003odQ8B?oIfMWofMWI02?o
fMWI00KoT92@o`000?n2PX;ofMWIokbl_?lL71`2o`000003o`h>3_oIfMWofMWI02OofMWI00?o[Jf]
o`000?l000000_l0000WomWIf@03odQ8B?l0003o000000Co000000?o[Jf]omWIfOoIfMT09OoIfMT0
1?m8B4So0000o`000?nOWilhomWIf@00G_oIfMT00oo:b/[o71`Loa`L7002ol[:bP03oa`L7?l0003o
b/[:02KofMWI00?o[Jf]odQ8B?l000000_l0000XomWIf@03ojf][Ol>3Pko000000Co000000?o3Ph>
ol[:b_oIfMT09OoIfMT00on2PX;o0000o`000004o`000003oh:2P_oIfMWofMWI02SofMWI00CoWinO
o`000?l0003o00009ooIfMT00on2PX;o0000o`000004o`000003oeIFE_oIfMWofMWI02KofMWI00Ko
T92@o`h>3_l0003o:b/[oh:2P_o:b/XeomWIf@00GooIfMT01_o:b/[oB4Q8o`000?l0003oB4Q8okbl
_2WofMWI00?ob/[:ofEUIOl>3Ph0:OoIfMT01oo:b/[oIFEUo`h>3_l0003o3Ph>oeIFE_o:b/X0:?oI
fMT01_nOWioo>CTio`000?l0003o71`Loi2@T2cofMWI00?oPX:2o`000?l000009ooIfMT00onl_;co
0000o`000004o`000003o`h>3_oIfMWofMWI02SofMWI00CoT92@oeIFE_l[:b_o0000=OoIfMT00?oo
fMWI/OoIfMT00?oofMWI/OoIfMT004[ofMWI1ol0003oomWIfF3ofMWI001;omWIf@05ofEUIOl0003o
0000o`000?n@T900oooIfMUQomWIf@00C?oIfMT3o`0000_ofMWIool0000bo`0002GofMWI001<omWI
f@?o00002ooIfMT00ol0003ofMWIomWIf@04omWIf@03o`000?oIfMWofMWI00OofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@07omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01ooIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00OofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01ooIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00OofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@06omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIomWIf@07omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWI
fOoIfMT01_oIfMT00ol0003ofMWIo`00000UomWIf@00C?oIfMT3o`0000_ofMWI00?o0000omWIfOoI
fMT01?oIfMT00ol0003ofMWIomWIf@0[omWIf@03o`000?oIfMWofMWI02_ofMWI00?o0000omWIfOoI
fMT0:ooIfMT00ol0003ofMWIomWIf@0/omWIf@03o`000?oIfMWofMWI02_ofMWI00?o0000omWIfOoI
fMT0:ooIfMT00ol0003ofMWIomWIf@0AomWIf@03o`000?oIfMWofMWI02?ofMWI000iomWIf@go0000
1_oIfMT3o`0000_ofMWI0ol0003EomWIfACoo`00@_oIfMT3o`0002GofMWI000iomWIf@go00001_oI
fMT3o`0000_ofMWI00?o0000omWIfOoIfMT0d?oIfMT5ool001CofMWI0ooo0011omWIf@03o`000?oI
fMWofMWI02?ofMWI001<omWIf@?o00002ooIfMT00ol0003ofMWIomWIf@3=omWIf@?oo`007?oIfMT4
ool003gofMWI00?o0000omWIfOoIfMT08ooIfMT004cofMWI0ol0000;omWIf@03o`000?oIfMWofMWI
0<[ofMWI0ooo000SomWIf@;oo`00>ooIfMT00ol0003ofMWIomWIf@0SomWIf@00C?oIfMT3o`0000_o
fMWI0_l00039omWIf@;oo`00:?oIfMT2ool003SofMWI0_l0000UomWIf@00C?oIfMT3o`0000_ofMWI
00?o0000omWIfOoIfMT0a_oIfMT2ool002cofMWI00?oo`00omWIfOoIfMT0=_oIfMT00ol0003ofMWI
omWIf@0SomWIf@00C?oIfMT3o`0000_ofMWI00?o0000omWIfOoIfMT0a?oIfMT2ool002oofMWI0_oo
000fomWIf@03o`000?oIfMWofMWI02?ofMWI001<omWIf@?o00002ooIfMT00ol0003ofMWIomWIf@32
omWIf@;oo`00<ooIfMT2ool003CofMWI00?o0000omWIfOoIfMT08ooIfMT004[ofMWI00?o:b/[oeIF
E_l000000_l0000;omWIf@03o`000?oIfMWofMWI0<3ofMWI0_oo000gomWIf@03ool00?oIfMWofMWI
037ofMWI00?o0000omWIfOoIfMT08ooIfMT004[ofMWI00?o[Jf]odQ8B?l000000_l0000;omWIf@;o
0000_ooIfMT2ool003[ofMWI0_oo000`omWIf@;o00009OoIfMT004cofMWI00?ob/[:ofEUIOl>3Ph0
2ooIfMT00ol0003ofMWIomWIf@2momWIf@03ool00?oIfMWofMWI03cofMWI0_oo000_omWIf@03o`00
0?oIfMWofMWI02?ofMWI001JomWIf@03o`000?oIfMWofMWI0;_ofMWI0_oo0011omWIf@03ool00?oI
fMWofMWI02cofMWI00?o0000omWIfOoIfMT08ooIfMT005[ofMWI00?o0000omWIfOoIfMT0^_oIfMT0
0ooo003ofMWIomWIf@12omWIf@;oo`00;?oIfMT00ol0003ofMWIomWIf@0SomWIf@00F_oIfMT2o`00
0;WofMWI0_oo0017omWIf@;oo`00:OoIfMT2o`0002GofMWI001JomWIf@03o`000?oIfMWofMWI0;Oo
fMWI00?oo`00omWIfOoIfMT0BOoIfMT00ooo003ofMWIomWIf@0WomWIf@03o`000?oIfMWofMWI02?o
fMWI001JomWIf@03o`000?oIfMWofMWI0;KofMWI00?oo`00omWIfOoIfMT0BooIfMT00ooo003ofMWI
omWIf@0VomWIf@03o`000?oIfMWofMWI02?ofMWI001JomWIf@03o`000?oIfMWofMWI0;GofMWI00?o
o`00omWIfOoIfMT0COoIfMT00ooo003ofMWIomWIf@0UomWIf@03o`000?oIfMWofMWI02?ofMWI001J
omWIf@03o`000?oIfMWofMWI0;CofMWI00?oo`00omWIfOoIfMT0CooIfMT00ooo003ofMWIomWIf@0T
omWIf@03o`000?oIfMWofMWI02?ofMWI000jomWIf@06ol[:b_li>CWo0000o`000?m8B4So_;bl1?oI
fMT00omUIFGo0000ofEUI@02omWIf@03ojf][Oli>CWo000000;o000000?o:b/[oh:2P_oIfMT02OoI
fMT2o`000;?ofMWI0_oo001ComWIf@;oo`008ooIfMT2o`0002GofMWI000iomWIf@03ol[:b_l>3Pko
71`L00;ob/[:00?o71`Lo`000?nl_;`00ooIfMT3o`0000;ofMWI1ol000000olL71co[Jf]omWIf@07
omWIf@03o`000?oIfMWofMWI0;7ofMWI00?oo`00omWIfOoIfMT0EOoIfMT00ooo003ofMWIomWIf@0Q
omWIf@03o`000?oIfMWofMWI02?ofMWI000iomWIf@03ob/[:ol0003oT92@00;ofMWI00?oT92@o`00
0?l[:b/00ooIfMT00omUIFGo0000ofEUI@02omWIf@0:ocTi>Ol0003o3Ph>oeIFE_n][JgofMWIokbl
_?lL71co0000ol[:bPOofMWI00?o0000omWIfOoIfMT0/?oIfMT00ooo003ofMWIomWIf@1GomWIf@03
ool00?oIfMWofMWI023ofMWI00?o0000omWIfOoIfMT08ooIfMT003SofMWI00Co[Jf]o`000?l0003o
_;bl0_oIfMT01?o:b/[o0000o`000?n][Jd>omWIf@03okbl_?l0003oB4Q800OofMWI00?o0000omWI
fOoIfMT0[ooIfMT00ooo003ofMWIomWIf@1IomWIf@03ool00?oIfMWofMWI01oofMWI00?o0000omWI
fOoIfMT08ooIfMT003SofMWI00?oEUIFo`000?l000001?oIfMT2o`000003oeIFE_oIfMWofMWI00go
fMWI00?o0000o`h>3_oIfMT01_oIfMT00ol0003ofMWIomWIf@2^omWIf@03ool00?oIfMWofMWI05_o
fMWI00?oo`00omWIfOoIfMT07_oIfMT00ol0003ofMWIomWIf@0SomWIf@00:?oIfMT=o`0000?ofMWI
00?o:b/[o`000?l000001?oIfMT2o`000003ob/[:ooIfMWofMWI00cofMWI00?oPX:2o`000?l00000
1ooIfMT3o`000:cofMWI0_oo001OomWIf@;oo`007?oIfMT3o`0002GofMWI000XomWIf@go00000ooI
fMT3o`0000CofMWI0ol0000=omWIf@04oh:2P_l0003o0000o`0000OofMWI00?o0000omWIfOoIfMT0
ZooIfMT00ooo003ofMWIomWIf@1QomWIf@03ool00?oIfMWofMWI01_ofMWI00?o0000omWIfOoIfMT0
8ooIfMT003SofMWI0ol00004omWIf@?o00002OoIfMT01?nl_;coWinOog=cLolL71`3o`000003ocTi
>OoIfMWofMWI00GofMWI00?o0000omWIfOoIfMT0Z_oIfMT00ooo003ofMWIomWIf@1SomWIf@03ool0
0?oIfMWofMWI01[ofMWI00?o0000omWIfOoIfMT08ooIfMT003SofMWI0ol00004omWIf@?o00002?oI
fMT00ol>3Pko0000o`000005o`000003ojf][OoIfMWofMWI00GofMWI00?o0000omWIfOoIfMT0ZOoI
fMT00ooo003ofMWIomWIf@1UomWIf@03ool00?oIfMWofMWI01WofMWI00?o0000omWIfOoIfMT08ooI
fMT003SofMWI0ol00004omWIf@?o00002?oIfMT00om8B4So0000o`000004o`000003oinOWooIfMWo
fMWI00KofMWI0_l0002YomWIf@03ool00?oIfMWofMWI06OofMWI00?oo`00omWIfOoIfMT05ooIfMT2
o`0002GofMWI000homWIf@03ob/[:ol0003o000000CofMWI0_l000000ol[:b_ofMWIomWIf@06omWI
f@07oh:2P_l0003o0000oa`L7?li>CWoPX:2ol[:bP09omWIf@03o`000?oIfMWofMWI0:OofMWI00?o
o`00omWIfOoIfMT0JOoIfMT00ooo003ofMWIomWIf@0GomWIf@03o`000?oIfMWofMWI02?ofMWI000h
omWIf@03oeIFE_l0003o000000CofMWI0_l000000omFEUKofMWIomWIf@06omWIf@03okbl_?l>3Pko
fMWI00gofMWI00?o0000omWIfOoIfMT0Y_oIfMT00ooo003ofMWIomWIf@1[omWIf@03ool00?oIfMWo
fMWI01KofMWI00?o0000omWIfOoIfMT08ooIfMT003SofMWI00Co[Jf]o`000?l0003ob/[:0_oIfMT0
1?o:b/[o0000o`000?n][Jd9omWIf@03o`h>3_nl_;cofMWI00cofMWI00?o0000omWIfOoIfMT0YOoI
fMT00ooo003ofMWIomWIf@1]omWIf@03ool00?oIfMWofMWI01GofMWI00?o0000omWIfOoIfMT08ooI
fMT003WofMWI00?o:b/[o`000?n@T9000_oIfMT00on@T93o0000ob/[:`0:omWIf@03odQ8B?l0003o
000000Co000000?o[Jf]omWIfOoIfMT01OoIfMT00ol0003ofMWIomWIf@2TomWIf@03ool00?oIfMWo
fMWI06oofMWI00?oo`00omWIfOoIfMT05?oIfMT00ol0003ofMWIomWIf@0SomWIf@00>OoIfMT00oo:
b/[o71`Loa`L7002ol[:bP03oa`L7?l0003ob/[:00[ofMWI00?oPX:2o`000?l000001?l000000omF
EUKofMWIomWIf@05omWIf@;o0000Y?oIfMT00ooo003ofMWIomWIf@1aomWIf@03ool00?oIfMWofMWI
01;ofMWI0_l0000UomWIf@00>_oIfMT01_o:b/[oB4Q8o`000?l0003oB4Q8okbl_0_ofMWI00?o_;bl
o`000?l000001?l000000ol>3PkofMWIomWIf@05omWIf@03o`000?oIfMWofMWI0:;ofMWI00?oo`00
omWIfOoIfMT0LooIfMT00ooo003ofMWIomWIf@0BomWIf@03o`000?oIfMWofMWI02?ofMWI001JomWI
f@03o`000?oIfMWofMWI0:3ofMWI0_oo001gomWIf@;oo`004_oIfMT00ol0003ofMWIomWIf@0SomWI
f@00F_oIfMT00ol0003ofMWIomWIf@2OomWIf@03ool00?oIfMWofMWI07WofMWI00?oo`00omWIfOoI
fMT03ooIfMT00ol0003ofMWIomWIf@0SomWIf@00F_oIfMT2o`0009oofMWI00?oo`00omWIfOoIfMT0
NooIfMT00ooo003ofMWIomWIf@0=omWIf@;o00009OoIfMT005[ofMWI00?o0000omWIfOoIfMT0WOoI
fMT00ooo003ofMWIomWIf@1momWIf@03ool00?oIfMWofMWI00gofMWI00?o0000omWIfOoIfMT08ooI
fMT005[ofMWI00?o0000omWIfOoIfMT0W?oIfMT00ooo003ofMWIomWIf@1oomWIf@03ool00?oIfMWo
fMWI00cofMWI00?o0000omWIfOoIfMT08ooIfMT005[ofMWI00?o0000omWIfOoIfMT0VooIfMT00ooo
003ofMWIomWIf@21omWIf@03ool00?oIfMWofMWI00_ofMWI00?o0000omWIfOoIfMT08ooIfMT005[o
fMWI00?o0000omWIfOoIfMT0V_oIfMT00ooo003ofMWIomWIf@23omWIf@03ool00?oIfMWofMWI00[o
fMWI00?o0000omWIfOoIfMT08ooIfMT004_ofMWI00Kob/[:ocTi>Ol0003o0000odQ8B?nl_;`9omWI
f@;o0000V_oIfMT00ooo003ofMWIomWIf@25omWIf@03ool00?oIfMWofMWI00SofMWI0_l0000UomWI
f@00B_oIfMT00oo:b/[o3Ph>oa`L7002ol[:bP03oa`L7?l0003o_;bl00SofMWI00?o0000omWIfOoI
fMT0V?oIfMT00ooo003ofMWIomWIf@27omWIf@03ool00?oIfMWofMWI00SofMWI00?o0000omWIfOoI
fMT08ooIfMT004[ofMWI00?o:b/[o`000?n@T9000_oIfMT00on@T93o0000ob/[:`08omWIf@03o`00
0?oIfMWofMWI09OofMWI00?oo`00omWIfOoIfMT0ROoIfMT00ooo003ofMWIomWIf@07omWIf@03o`00
0?oIfMWofMWI02?ofMWI0019omWIf@04ojf][Ol0003o0000okbl_0;ofMWI00Cob/[:o`000?l0003o
[Jf]1ooIfMT00ol0003ofMWIomWIf@2FomWIf@03ool00?oIfMWofMWI08_ofMWI00?oo`00omWIfOoI
fMT01_oIfMT00ol0003ofMWIomWIf@0SomWIf@00BOoIfMT00omFEUKo0000o`000004omWIf@;o0000
00?oEUIFomWIfOoIfMT01OoIfMT00ol0003ofMWIomWIf@2EomWIf@03ool00?oIfMWofMWI08gofMWI
00?oo`00omWIfOoIfMT01OoIfMT00ol0003ofMWIomWIf@0SomWIf@00BOoIfMT00ol[:b_o0000o`00
0004omWIf@;o000000?o:b/[omWIfOoIfMT01OoIfMT3o`0000CofMWI0_oo002>omWIf@03ool00?oI
fMWofMWI08oofMWI00?oo`00omWIfOoIfMT00_oIfMT3o`0002GofMWI0019omWIf@?o00001?oIfMT3
o`0000OofMWI00?o0000omWIfOoIfMT01_oIfMT00ooo003ofMWIomWIf@2;omWIf@03ool00?oIfMWo
fMWI09KofMWI00?o0000omWIfOoIfMT08ooIfMT004WofMWI0ol00004omWIf@?o00001ooIfMT00ol0
003ofMWIomWIf@07omWIf@03ool00?oIfMWofMWI08WofMWI00?oo`00omWIfOoIfMT0UooIfMT00ol0
003ofMWIomWIf@0SomWIf@00BOoIfMT3o`0000CofMWI0ol00007omWIf@03o`000?oIfMWofMWI00So
fMWI00?oo`00omWIfOoIfMT0QooIfMT00ooo003ofMWIomWIf@2HomWIf@03o`000?oIfMWofMWI02?o
fMWI0019omWIf@?o00001?oIfMT3o`0000OofMWI0_l0000:omWIf@03ool00?oIfMWofMWI08GofMWI
00?oo`00omWIfOoIfMT0V?oIfMT2o`0002GofMWI0019omWIf@03ob/[:ol0003o000000CofMWI0_l0
00000ol[:b_ofMWIomWIf@05omWIf@03o`000?oIfMWofMWI00[ofMWI00?oo`00omWIfOoIfMT0PooI
fMT00ooo003ofMWIomWIf@2JomWIf@03o`000?oIfMWofMWI02?ofMWI0019omWIf@03oeIFE_l0003o
000000CofMWI0_l000000omFEUKofMWIomWIf@05omWIf@03o`000?oIfMWofMWI00_ofMWI00?oo`00
omWIfOoIfMT0POoIfMT00ooo003ofMWIomWIf@2KomWIf@03o`000?oIfMWofMWI02?ofMWI0019omWI
f@04ojf][Ol0003o0000ol[:bP;ofMWI00Cob/[:o`000?l0003o[Jf]1ooIfMT00ol0003ofMWIomWI
f@0<omWIf@03ool00?oIfMWofMWI07oofMWI00?oo`00omWIfOoIfMT0W?oIfMT00ol0003ofMWIomWI
f@0SomWIf@00B_oIfMT00ol[:b_o0000oi2@T002omWIf@03oi2@T?l0003o:b/[00SofMWI00?o0000
omWIfOoIfMT03OoIfMT00ooo003ofMWIomWIf@1momWIf@03ool00?oIfMWofMWI09gofMWI00?o0000
omWIfOoIfMT08ooIfMT004[ofMWI00?ob/[:oa`L7?lL71`00_o:b/X00olL71co0000ol[:bP08omWI
f@;o00003ooIfMT00ooo003ofMWIomWIf@1komWIf@03ool00?oIfMWofMWI09gofMWI0_l0000UomWI
f@00BooIfMT01_o:b/[oB4Q8o`000?l0003oB4Q8okbl_0WofMWI00?o0000omWIfOoIfMT03ooIfMT0
0ooo003ofMWIomWIf@1iomWIf@03ool00?oIfMWofMWI09oofMWI00?o0000omWIfOoIfMT08ooIfMT0
05[ofMWI00?o0000omWIfOoIfMT04?oIfMT2ool007SofMWI00?oo`00omWIfOoIfMT0X?oIfMT00ol0
003ofMWIomWIf@0SomWIf@00F_oIfMT00ol0003ofMWIomWIf@0BomWIf@03ool00?oIfMWofMWI07?o
fMWI0_oo002SomWIf@03o`000?oIfMWofMWI02?ofMWI001JomWIf@03o`000?oIfMWofMWI01?ofMWI
00?oo`00omWIfOoIfMT0LOoIfMT00ooo003ofMWIomWIf@2SomWIf@03o`000?oIfMWofMWI02?ofMWI
001JomWIf@;o00005OoIfMT00ooo003ofMWIomWIf@1_omWIf@03ool00?oIfMWofMWI0:?ofMWI0_l0
000UomWIf@00F_oIfMT00ol0003ofMWIomWIf@0EomWIf@03ool00?oIfMWofMWI06gofMWI00?oo`00
omWIfOoIfMT0YOoIfMT00ol0003ofMWIomWIf@0SomWIf@00F_oIfMT00ol0003ofMWIomWIf@0FomWI
f@03ool00?oIfMWofMWI06_ofMWI00?oo`00omWIfOoIfMT0Y_oIfMT00ol0003ofMWIomWIf@0SomWI
f@00F_oIfMT00ol0003ofMWIomWIf@0GomWIf@03ool00?oIfMWofMWI06SofMWI0_oo002YomWIf@03
o`000?oIfMWofMWI02?ofMWI000jomWIf@06ol[:b_li>CWo0000o`000?m8B4So_;bl1?oIfMT00omU
IFGo0000ofEUI@02omWIf@03ojf][Oli>CWo000000;o000000?o:b/[oh:2P_oIfMT02OoIfMT2o`00
01WofMWI00?oo`00omWIfOoIfMT0I_oIfMT00ooo003ofMWIomWIf@2XomWIf@;o00009OoIfMT003Wo
fMWI00?ob/[:o`h>3_lL71`00_o:b/X00olL71co0000okbl_003omWIf@?o00000_oIfMT7o`000003
oa`L7?n][JgofMWI00OofMWI00?o0000omWIfOoIfMT06OoIfMT00ooo003ofMWIomWIf@1TomWIf@03
ool00?oIfMWofMWI0:[ofMWI00?o0000omWIfOoIfMT08ooIfMT003WofMWI00?o:b/[o`000?n@T900
0_oIfMT00on@T93o0000ob/[:`03omWIf@03ofEUIOl0003oIFEU00;ofMWI00[o>CTio`000?l>3Pko
EUIFojf][OoIfMWo_;bloa`L7?l0003ob/[:1ooIfMT00ol0003ofMWIomWIf@0JomWIf@03ool00?oI
fMWofMWI06;ofMWI00?oo`00omWIfOoIfMT0ZooIfMT00ol0003ofMWIomWIf@0SomWIf@00>?oIfMT0
1?n][Jgo0000o`000?nl_;`2omWIf@04ol[:b_l0003o0000ojf][@kofMWI00?o_;blo`000?m8B4P0
1ooIfMT00ol0003ofMWIomWIf@0KomWIf@03ool00?oIfMWofMWI063ofMWI00?oo`00omWIfOoIfMT0
[?oIfMT00ol0003ofMWIomWIf@0SomWIf@00>?oIfMT00omFEUKo0000o`000004omWIf@;o000000?o
EUIFomWIfOoIfMT03OoIfMT00ol0003o3Ph>omWIf@06omWIf@03o`000?oIfMWofMWI01cofMWI00?o
o`00omWIfOoIfMT0G_oIfMT00ooo003ofMWIomWIf@2]omWIf@03o`000?oIfMWofMWI02?ofMWI000h
omWIf@03ob/[:ol0003o000000CofMWI0_l000000ol[:b_ofMWIomWIf@0<omWIf@03oh:2P_l0003o
000000OofMWI0ol0000MomWIf@;oo`00G?oIfMT2ool00:kofMWI0ol0000UomWIf@00>?oIfMT3o`00
00CofMWI0ol0000=omWIf@04oh:2P_l0003o0000o`0000OofMWI00?o0000omWIfOoIfMT07ooIfMT0
0ooo003ofMWIomWIf@1HomWIf@03ool00?oIfMWofMWI0;3ofMWI00?o0000omWIfOoIfMT08ooIfMT0
03SofMWI0ol00004omWIf@?o00002OoIfMT01?nl_;coWinOog=cLolL71`3o`000003ocTi>OoIfMWo
fMWI00GofMWI00?o0000omWIfOoIfMT08?oIfMT00ooo003ofMWIomWIf@1FomWIf@03ool00?oIfMWo
fMWI0;7ofMWI00?o0000omWIfOoIfMT08ooIfMT003SofMWI0ol00004omWIf@?o00002?oIfMT00ol>
3Pko0000o`000005o`000003ojf][OoIfMWofMWI00GofMWI00?o0000omWIfOoIfMT08OoIfMT00ooo
003ofMWIomWIf@1DomWIf@03ool00?oIfMWofMWI0;;ofMWI00?o0000omWIfOoIfMT08ooIfMT003So
fMWI0ol00004omWIf@?o00002?oIfMT00om8B4So0000o`000004o`000003oinOWooIfMWofMWI00Ko
fMWI0_l0000SomWIf@03ool00?oIfMWofMWI057ofMWI0_oo002domWIf@;o00009OoIfMT003SofMWI
00?o:b/[o`000?l000001?oIfMT2o`000003ob/[:ooIfMWofMWI00KofMWI00OoPX:2o`000?l0003o
71`LocTi>On2PX;ob/[:00WofMWI00?o0000omWIfOoIfMT08ooIfMT2ool0053ofMWI00?oo`00omWI
fOoIfMT0]OoIfMT00ol0003ofMWIomWIf@0SomWIf@00>?oIfMT00omFEUKo0000o`000004omWIf@;o
000000?oEUIFomWIfOoIfMT01_oIfMT00onl_;co3Ph>omWIf@0=omWIf@03o`000?oIfMWofMWI02Go
fMWI00?oo`00omWIfOoIfMT0C?oIfMT00ooo003ofMWIomWIf@2fomWIf@03o`000?oIfMWofMWI02?o
fMWI000homWIf@04ojf][Ol0003o0000ol[:bP;ofMWI00Cob/[:o`000?l0003o[Jf]2OoIfMT00ol>
3Pko_;blomWIf@0<omWIf@03o`000?oIfMWofMWI02KofMWI00?oo`00omWIfOoIfMT0B_oIfMT00ooo
003ofMWIomWIf@2gomWIf@03o`000?oIfMWofMWI02?ofMWI000iomWIf@03ob/[:ol0003oT92@00;o
fMWI00?oT92@o`000?l[:b/02_oIfMT00om8B4So0000o`000004o`000003ojf][OoIfMWofMWI00Go
fMWI00?o0000omWIfOoIfMT09ooIfMT00ooo003ofMWIomWIf@18omWIf@03ool00?oIfMWofMWI0;So
fMWI00?o0000omWIfOoIfMT08ooIfMT003WofMWI00?ob/[:oa`L7?lL71`00_o:b/X00olL71co0000
ol[:bP0:omWIf@03oh:2P_l0003o000000Co000000?oEUIFomWIfOoIfMT01OoIfMT2o`0002WofMWI
00?oo`00omWIfOoIfMT0AOoIfMT2ool00;[ofMWI0_l0000UomWIf@00>_oIfMT01_o:b/[oB4Q8o`00
0?l0003oB4Q8okbl_0_ofMWI00?o_;blo`000?l000001?l000000ol>3PkofMWIomWIf@05omWIf@03
o`000?oIfMWofMWI02WofMWI0_oo0014omWIf@03ool00?oIfMWofMWI0;_ofMWI00?o0000omWIfOoI
fMT08ooIfMT005[ofMWI00?o0000omWIfOoIfMT0:ooIfMT00ooo003ofMWIomWIf@0oomWIf@;oo`00
__oIfMT00ol0003ofMWIomWIf@0SomWIf@00F_oIfMT00ol0003ofMWIomWIf@0/omWIf@;oo`00?_oI
fMT00ooo003ofMWIomWIf@2nomWIf@03o`000?oIfMWofMWI02?ofMWI001JomWIf@03o`000?oIfMWo
fMWI02kofMWI0_oo000jomWIf@;oo`00`OoIfMT00ol0003ofMWIomWIf@0SomWIf@00F_oIfMT2o`00
037ofMWI00?oo`00omWIfOoIfMT0=_oIfMT00ooo003ofMWIomWIf@30omWIf@;o00009OoIfMT005[o
fMWI00?o0000omWIfOoIfMT0<OoIfMT2ool003CofMWI0_oo0034omWIf@03o`000?oIfMWofMWI02?o
fMWI001JomWIf@03o`000?oIfMWofMWI03?ofMWI00?oo`00omWIfOoIfMT0<?oIfMT00ooo003ofMWI
omWIf@34omWIf@03o`000?oIfMWofMWI02?ofMWI001JomWIf@03o`000?oIfMWofMWI03CofMWI0ooo
000]omWIf@;oo`00aooIfMT00ol0003ofMWIomWIf@0SomWIf@00B_oIfMT7o`0000WofMWI0_l0000h
omWIf@?oo`009ooIfMT3ool00<SofMWI0_l0000UomWIf@00BooIfMT01OmUIFGo0000o`000?l0003o
T92@00[ofMWI00?o0000omWIfOoIfMT0>_oIfMT3ool0027ofMWI0ooo003<omWIf@03o`000?oIfMWo
fMWI02?ofMWI001<omWIf@?o00002ooIfMT00ol0003ofMWIomWIf@0momWIf@Coo`006_oIfMT3ool0
0<oofMWI00?o0000omWIfOoIfMT08ooIfMT004cofMWI0ol0000;omWIf@03o`000?oIfMWofMWI047o
fMWI0ooo000DomWIf@?oo`00d_oIfMT00ol0003ofMWIomWIf@0SomWIf@00C?oIfMT3o`0000_ofMWI
00?o0000omWIfOoIfMT0A?oIfMT4ool000WofMWI1ooo003EomWIf@03o`000?oIfMWofMWI02?ofMWI
001<omWIf@?o00002ooIfMT3o`0000CofMWI00?o0000omWIfOoIfMT0:ooIfMT00ol0003ofMWIomWI
f@0ComWIf@Woo`003ooIfMT00ol0003ofMWIomWIf@0[omWIf@03o`000?oIfMWofMWI02cofMWI00?o
0000omWIfOoIfMT0:ooIfMT00ol0003ofMWIomWIf@0[omWIf@03o`000?oIfMWofMWI00oofMWI0ol0
000UomWIf@00C?oIfMT3o`0000_ofMWI00?o0000omWIfOoIfMT01?oIfMT00ol0003ofMWIomWIf@07
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01ooIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00OofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@07
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00OofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@07
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01_oIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOoIfMT01ooIfMT00ol0003ofMWIomWIf@06
omWIf@03o`000?oIfMWofMWI00KofMWI00?o0000omWIfOl000009OoIfMT004cofMWI0ol0000;omWI
fOoo0000<_l0000UomWIf@00C?oIfMT3o`000?oofMWIH_oIfMT004cofMWI0ol0003oomWIfF;ofMWI
001<omWIf@?o0000oooIfMURomWIf@00C?oIfMT3o`000?oofMWIH_oIfMT004cofMWI0ol0003oomWI
fF;ofMWI001:omWIf@03ob/[:omFEUKo000000;o0000oooIfMURomWIf@00B_oIfMT00on][JgoB4Q8
o`000002o`000?oofMWIH_oIfMT004cofMWI00?ob/[:ofEUIOl>3Ph0oooIfMURomWIf@00oooIfMVa
omWIf@00oooIfMVaomWIf@00\
\>"],
  ImageRangeCache->{{{0, 431}, {136.438, 0}} -> {-2.12463, -1.68629, \
0.0325777, 0.0325777}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[208]="]
}, Open  ]],

Cell["\<\
Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam \
nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. \
Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit \
lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure \
dolor in hendrerit in vulputate velit esse molestie consequat, vel illum \
dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio \
dignissim qui blandit praesent luptatum zzril delenit a\
\>", "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        SubscriptBox["k", 
          StyleBox["b1",
            FontSlant->"Plain"]], "=", 
        RowBox[{
          SubscriptBox["k", 
            StyleBox["s1",
              FontSlant->"Plain"]], \(\[Xi]\_1\%\(1 - \[Alpha]\)\)}]}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        SubscriptBox["k", 
          StyleBox["f1",
            FontSlant->"Plain"]], "=", 
        RowBox[{
          SubscriptBox["k", 
            StyleBox["s1",
              FontSlant->"Plain"]], \(\[Xi]\_1\%\(-\[Alpha]\)\)}]}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        SubscriptBox["k", 
          StyleBox["b2",
            FontSlant->"Plain"]], "=", 
        RowBox[{
          SubscriptBox["k", 
            StyleBox["s2",
              FontSlant->"Plain"]], \(\[Xi]\_2\%\(1 - \[Alpha]\)\)}]}], 
      TraditionalForm], "\n", 
    FormBox[
      RowBox[{
        SubscriptBox["k", 
          StyleBox["f2",
            FontSlant->"Plain"]], 
        "=", \(\(k\_s2\) \[Xi]\_2\%\(-\[Alpha]\)\)}], 
      TraditionalForm]}]]], "NumberedEquation",
  CellTags->"eqn2"],

Cell["\<\
Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam \
nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. \
Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit \
lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure \
dolor in hendrerit in vulputate velit esse molestie consequat, vel illum \
dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio \
dignissim qui blandit praesent luptatum zzril delenit a\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["\[CapitalGamma]", 
            StyleBox["A",
              FontSlant->"Plain"]], "+", 
          SubscriptBox["\[CapitalGamma]", 
            StyleBox["B",
              FontSlant->"Plain"]], "+", 
          SubscriptBox["\[CapitalGamma]", 
            StyleBox["C",
              FontSlant->"Plain"]]}], "=", 
        SubscriptBox["\[CapitalGamma]", 
          StyleBox["T",
            FontSlant->"Plain"]]}], TraditionalForm]]]], "NumberedEquation"],

Cell["\<\
Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam \
nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. \
Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit \
lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure \
dolor in hendrerit in vulputate velit esse molestie consequat, vel illum \
dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio \
dignissim qui blandit praesent luptatum zzril delenit a\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox["x", 
            StyleBox["A",
              FontSlant->"Plain"]], "+", 
          SubscriptBox["x", 
            StyleBox["B",
              FontSlant->"Plain"]], "+", 
          SubscriptBox["x", 
            StyleBox["C",
              FontSlant->"Plain"]]}], "=", "1"}], 
      TraditionalForm]]]], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  ButtonBox["Step two",
    ButtonStyle->"SectionButton"]
}], "Section"],

Cell[TextData[{
  "Next step is to save this notebook as ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  ". Go to the menu and select File\[RightPointer]Save As Special\[Ellipsis] \
I have saved this notebook as test.tex. The figures in your notebook will be \
saved as separate EPS files."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  ButtonBox["Step three",
    ButtonStyle->"SectionButton"]
}], "Section"],

Cell[TextData[{
  "Next step you can either edit the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file. On the Mac I have used ",
  ButtonBox["TeXShop",
    ButtonData:>{
      URL[ "http://www.uoregon.edu/~koch/texshop"], None},
    ButtonStyle->"Hyperlink"],
  " to edit the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file but there are others around such as ",
  ButtonBox["iTeXMac",
    ButtonData:>{
      URL[ "http://itexmac.sourceforge.net"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["texmaker",
    ButtonData:>{
      URL[ "http://www.xm1math.net/texmaker/"], None},
    ButtonStyle->"Hyperlink"],
  ". If you do not have any of these programs use a text editor.\nOn the Mac \
you need to change your typesetting method from \"pdftex\" to \"",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " and Ghostscript.\" I've found this change necessary in order to get the \
EPS files included correctly \[Ellipsis]however I might be showing my \
ignorance of ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"L", 
          StyleBox[
            AdjustmentBox["A",
              BoxMargins->{{-0.36, -0.1}, {0, 0}},
              BoxBaselineShift->-0.2],
            FontSize->Smaller], "T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " here. Perhaps someone can offer some better instructions here. Typeset \
the document and check that everything is okay."
}], "Text"],

Cell[TextData[{
  "You will notice that the linebreaks in eqns (",
  
  CounterBox["NumberedEquation", "eqn1"],
  ") and (",
  
  CounterBox["NumberedEquation", "eqn2"],
  ") have not been converted correctly. At the end of the day we are not \
seeking a perfect ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"L", 
          StyleBox[
            AdjustmentBox["A",
              BoxMargins->{{-0.36, -0.1}, {0, 0}},
              BoxBaselineShift->-0.2],
            FontSize->Smaller], "T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " document but some changes need to be made in order to get the conversion \
to RTF to work correctly. For example if we do nothing now we get the \
test.rtf file that can be found in this folder."
}], "Text"],

Cell[TextData[{
  "If you open the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file in either TeXShop or similar program or a text editor you will \
notice the equations are wrapped by ",
  StyleBox["begin{equation}",
    FontFamily->"Helvetica",
    FontSize->10],
  " and ",
  StyleBox["end{equation}",
    FontFamily->"Helvetica",
    FontSize->10],
  ". For example eqn (",
  
  CounterBox["NumberedEquation", "eqn2"],
  ") in full is:"
}], "Text"],

Cell["\<\
\\begin{equation}k_{\\text{b1}}=k_{\\text{s1}}\\xi _1^{1-\\alpha \
}\\\\
\\\\
k_{\\text{f1}}=k_{\\text{s1}}\\xi _1^{-\\alpha }\\\\
\\\\
k_{\\text{b2}}=k_{\\text{s2}}\\xi _2^{1-\\alpha }\\\\
\\\\
k_{\\text{f2}}=k_{\\text{s2}}\\xi _2^{-\\alpha }\\end{equation}\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->10],

Cell[TextData[{
  "Our objective is not to make the perfect ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"L", 
          StyleBox[
            AdjustmentBox["A",
              BoxMargins->{{-0.36, -0.1}, {0, 0}},
              BoxBaselineShift->-0.2],
            FontSize->Smaller], "T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " document, though any input from readers would be welcome, it is to modify \
the ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"T", 
          AdjustmentBox["E",
            BoxMargins->{{-0.075, -0.085}, {0, 0}},
            BoxBaselineShift->0.5], "X"}]]]],
  " file so that all equations are converted to editable fields in the RTF \
file. As it stands an error is produced when the conversion of eqns (",
  
  CounterBox["NumberedEquation", "eqn1"],
  ") and (",
  
  CounterBox["NumberedEquation", "eqn2"],
  ") is attempted; see the file test.rtf. To fix this you need to go to all \
the multi-line equations cells in your notebook and change ",
  StyleBox["{equation}",
    FontFamily->"Helvetica",
    FontSize->10],
  " to ",
  StyleBox["{eqnarray}",
    FontFamily->"Helvetica",
    FontSize->10],
  ". Save the file as test1.tex."
}], "Text"],

Cell["\<\
\\begin{eqnarray}k_{\\text{b1}}=k_{\\text{s1}}\\xi _1^{1-\\alpha \
}\\\\
\\\\
k_{\\text{f1}}=k_{\\text{s1}}\\xi _1^{-\\alpha }\\\\
\\\\
k_{\\text{b2}}=k_{\\text{s2}}\\xi _2^{1-\\alpha }\\\\
\\\\
k_{\\text{f2}}=k_{\\text{s2}}\\xi _2^{-\\alpha }\\end{eqnarray}\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Section"],
  ". ",
  ButtonBox["Step four",
    ButtonStyle->"SectionButton"]
}], "Section"],

Cell[TextData[{
  "In UNIX open a terminal and type:\n\n",
  StyleBox["latex2rtf test1.tex",
    FontFamily->"Monaco",
    FontSize->9],
  "\n\nThere are various switches that are described in the latex2rtf \
documentation but I have found that the default settings work fine. Quite a \
few messages with be generated but an RTF file will be created. Open the RTF \
file, tests1.rtf, in Word. To ensure correct equation formatting double click \
on each the equations. This will open them in the equation editor window. \
Close the equation editor window without making and changes. Thats it. \
Everything should now look as nice as it possible can in Word."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1241}, {0, 832}},
WindowToolbars->"EditBar",
WindowSize->{906, 810},
WindowMargins->{{7, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "eqn1"->{
    Cell[8836, 256, 6417, 187, 212, "NumberedEquation",
      CellTags->"eqn1"]},
  "eqn2"->{
    Cell[55779, 1672, 1154, 38, 122, "NumberedEquation",
      CellTags->"eqn2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"eqn1", 66573, 2014},
  {"eqn2", 66667, 2017}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 138, 5, 260, "Title"],
Cell[1917, 60, 191, 6, 64, "Text"],
Cell[2111, 68, 27, 0, 38, "Text"],
Cell[2141, 70, 61, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[2227, 74, 128, 6, 89, "Section"],
Cell[2358, 82, 773, 16, 168, "Text"],
Cell[3134, 100, 389, 7, 90, "Text"],
Cell[3526, 109, 832, 21, 116, "Text"],
Cell[4361, 132, 877, 21, 116, "Text"],
Cell[5241, 155, 1096, 26, 168, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6374, 186, 124, 6, 89, "Section"],
Cell[6501, 194, 2088, 53, 248, "Text"],
Cell[8592, 249, 92, 1, 39, "NumberedEquation"],
Cell[8687, 252, 146, 2, 45, "NumberedEquation"],
Cell[8836, 256, 6417, 187, 212, "NumberedEquation",
  CellTags->"eqn1"],
Cell[15256, 445, 536, 8, 142, "Text"],

Cell[CellGroupData[{
Cell[15817, 457, 89, 2, 61, "Input"],
Cell[15909, 461, 39157, 1192, 162, 17626, 922, "GraphicsData", "PostScript", \
"Graphics"],
Cell[55069, 1655, 156, 4, 81, "Output"]
}, Open  ]],
Cell[55240, 1662, 536, 8, 142, "Text"],
Cell[55779, 1672, 1154, 38, 122, "NumberedEquation",
  CellTags->"eqn2"],
Cell[56936, 1712, 536, 8, 142, "Text"],
Cell[57475, 1722, 549, 15, 38, "NumberedEquation"],
Cell[58027, 1739, 536, 8, 142, "Text"],
Cell[58566, 1749, 419, 13, 38, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59022, 1767, 124, 6, 89, "Section"],
Cell[59149, 1775, 440, 11, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59626, 1791, 126, 6, 89, "Section"],
Cell[59755, 1799, 1906, 54, 168, "Text"],
Cell[61664, 1855, 837, 23, 90, "Text"],
Cell[62504, 1880, 596, 21, 64, "Text"],
Cell[63103, 1903, 325, 11, 159, "Text"],
Cell[63431, 1916, 1284, 38, 116, "Text"],
Cell[64718, 1956, 325, 11, 159, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65080, 1972, 125, 6, 89, "Section"],
Cell[65208, 1980, 670, 12, 243, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

